@@ -3,19 +3,15 @@
 # Copyright (C) 2007, 2008 Red Hat Inc.
 # Author: Will Woods <wwoods@redhat.com>
 #
-# This program is free software; you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by the
-# Free Software Foundation; either version 2 of the License, or (at your
-# option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
-# the full text of the license.
+# This work is licensed under the GNU GPLv2 or later.
+# See the COPYING file in the top-level directory.
 
 from .apiversion import version, __version__
 from .base import Bugzilla
-from .transport import BugzillaError
-from .rhbugzilla import RHBugzilla
+from .exceptions import BugzillaError
 from .oldclasses import (Bugzilla3, Bugzilla32, Bugzilla34, Bugzilla36,
         Bugzilla4, Bugzilla42, Bugzilla44,
-        NovellBugzilla, RHBugzilla3, RHBugzilla4)
+        NovellBugzilla, RHBugzilla, RHBugzilla3, RHBugzilla4)
 
 
 # This is the public API. If you are explicitly instantiating any other
