@@ -125,8 +125,7 @@ def _setup_root_parser():
         help="Don't save any bugzilla cookies or tokens to disk, and "
              "don't use any pre-existing credentials.")
 
-    p.add_argument('--cookiefile', default=None,
-            help="cookie file to use for bugzilla authentication")
+    p.add_argument('--cookiefile', default=None, help=argparse.SUPPRESS)
     p.add_argument('--tokenfile', default=None,
             help="token file to use for bugzilla authentication")
 
@@ -662,7 +661,7 @@ def _do_info(bz, opt):
     elif opt.component_owners:
         details = bz.getcomponentsdetails(productname)
         for c in sorted(_filter_components(details)):
-            print(u"%s: %s" % (c, details[c]['default_assigned_to']))
+            print("%s: %s" % (c, details[c]['default_assigned_to']))
 
 
 def _convert_to_outputformat(output):
